# Textual-Cookbook

This repo contains a collection of examples and recipes for using the Textual framework to build terminal applications. Every example in this repository is runnable, and you can use them as a starting point for your own projects, or just learn how to do nifty things with Textual.

The examples are currently organized into the following categories:

- **Animation Effects**: Examples that demonstrate how to create various animation effects in Textual applications.
- **Architecture Patterns**: Examples that showcase different architectural patterns for building Textual applications.
- **Modifying Widgets**: Examples that show how to modify existing widgets or create new ones.
- **Styling and Colors**: Examples that demonstrate how to style Textual applications and use colors effectively.
- **Textual API Usage**: Examples that illustrate how to use the Textual API for various tasks.
- **Tips and Tricks**: A collection of miscellaneous examples that don't fit into the other categories.

All examples are tested with Nox against multiple verions of Textual (back to 1.0.0) in order to see how far back the examples work. Nearly all of them work all the way back to 1.0.0 with a few exceptions. To view the results of the tests, click the link below:

## [Textual Cookbook Test Results](https://ttygroup.github.io/textual-cookbook/reports/)
